%define		bin_name mp-5
%define		upstream_name %{bin_name}.x

%bcond_with pcre

Name:		mp
Version:	5.60
Release:	%mkrel 2
Summary:	Minimum Profit Text Editor
Group:		Editors
License:	GPLv2
URL:		https://triptico.com/software/mp.html
Source0:	https://github.com/ttcdt/mp-5.x/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	mp_doccer
%if %{with pcre}
BuildRequires:	pkgconfig(libpcre)
%endif
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	ncursesw-devel
BuildRequires:	grutatxt
BuildRequires:	glibc-devel
BuildRequires:	gettext

Provides:	%{name}-5 = %{version}-%{release}

%description
A text editor for programmers including the following features:

- Fully scriptable using a C-like scripting language.
- Unlimited undo levels.
- Complete Unicode support.
- Multiple files can be edited at the same time and blocks copied and pasted
  among them.
- Syntax highlighting for many popular languages / file formats: C, C++, Perl,
  Shell Scripts, Ruby, Php, Python, HTML...
- Creative use of tags: tags created by the external utility ctags are used to
  move instantaneously to functions or variables inside your current source
  tree. Tags are visually highlighted (underlined), and symbol completion can
  be triggered to avoid typing your own function names over and over.
- Intelligent help system: pressing F1 over any word of a text being edited
  triggers the underlying system help (calling man when editing C or Shell
  files, perldoc with Perl, ri on Ruby...).
- Understandable interface: drop-down menus, reasonable default key bindings.
- Configurable keys, menus and colors.
- Text templates can be easily defined / accessed.
- Multiplatform: Console/curses, Qt4, KDE4, GTK+, MS Windows (both windowed
  and console).
- Automatic indentation, word wrapping, internal grep, learning / repeating
  functions.
- Spellchecking support (via the ispell package).
- Multilingual.
- Password-protected, encrypted text files (using the ARCFOUR algorithm).
- It helps you abandon vi, emacs and other six-legged freaks definitely.

%prep
%autosetup -p1 -n %{upstream_name}-%{version}

%build
%set_build_flags
# An error with Qt5 detection and compilation occurs without this setting
#export CPP="g++ -std=gnu++11"
export CFLAGS="%{optflags} -fpermissive"
./config.sh \
	--prefix=%{_prefix} \
	--with-moc=%{_qt5_bindir}/moc \
	--with-qt5 \
	--without-qt4 \
	--without-gtk \
	--without-win32 \
	%{?with_pcre:--with-pcre} \
	--with-curses
%make_build

%install
mkdir -p %{buildroot}%{_bindir}

%make_install DESTDIR=%{buildroot}

( cd %{buildroot}%{_bindir} && ln -s mp-5 mp )
# Debian uses "mped" for this application
( cd %{buildroot}%{_bindir} && ln -s mp-5 mped )

# Make the man page
grutatxt -m man -t "Minimum Profit" < doc/mp_man.txt > %{bin_name}.1
install -m 0644 %{bin_name}.1 %{buildroot}%{_mandir}/man1/%{bin_name}.1

#find_lang mp

%files
#-f mp.lang
%license LICENSE
%doc README RELEASE_NOTES *sample TODO* doc/*
%doc mpsl/README* mpsl/doc/*
%doc mpdm/doc/*
%{_docdir}/%{bin_name}/
%{_bindir}/%{bin_name}
%{_bindir}/%{name}
%{_bindir}/%{name}ed
#{_bindir}/mpsl
#{_datadir}/#{bin_name}/
%{_mandir}/man1/%{bin_name}*


%changelog
* Sun Apr 16 2023 daviddavid <daviddavid> 5.60-2.mga9
+ Revision: 1953390
- disable old pcre support in Mageia 9 (mga#31791)

* Sun Feb 19 2023 kekepower <kekepower> 5.60-1.mga9
+ Revision: 1944147
- Update to version 5.60

* Wed Feb 01 2023 kekepower <kekepower> 5.59-1.mga9
+ Revision: 1937436
- Update to version 5.59

* Sun Apr 03 2022 umeabot <umeabot> 5.36-4.mga9
+ Revision: 1841884
- Mageia 9 Mass Rebuild

* Tue Feb 18 2020 umeabot <umeabot> 5.36-3.mga8
+ Revision: 1539206
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Sun Dec 01 2019 kekepower <kekepower> 5.36-2.mga8
+ Revision: 1463913
- Update to version 5.36
- Update mpdm and mpsl to version 2.54

* Sun Mar 31 2019 umeabot <umeabot> 5.31-2.mga7
+ Revision: 1383480
- Qt5 Rebuild

* Sun Mar 17 2019 kekepower <kekepower> 5.31-1.mga7
+ Revision: 1378425
- Update to version 5.31

* Thu Dec 20 2018 kekepower <kekepower> 5.2.15-2.mga7
+ Revision: 1343838
- Fixed an error in Patch0
- Update to version 5.2.15

* Mon Dec 17 2018 kekepower <kekepower> 5.2.14-1.mga7
+ Revision: 1342366
- Update to version 5.2.14
- Update MPSL to version 2.2.4

* Tue Dec 11 2018 kekepower <kekepower> 5.2.13-6.mga7
+ Revision: 1340235
- Re-enable building with curses

* Sun Nov 25 2018 kekepower <kekepower> 5.2.13-5.mga7
+ Revision: 1334084
- Disable building with ncurses for now

* Sun Sep 23 2018 umeabot <umeabot> 5.2.13-4.mga7
+ Revision: 1299611
- Mageia 7 Mass Rebuild

* Tue Feb 27 2018 kekepower <kekepower> 5.2.13-3.mga7
+ Revision: 1205559
- Enable Qt5
- Add patch for Qt5 detection, submitted upstream
- Add symlink to mp and mped

* Tue Feb 27 2018 kekepower <kekepower> 5.2.13-1.mga7
+ Revision: 1205383
- Update to version 5.2.13
- Update to mpdm-2.1.7
- Remove ANSI colors patch

* Sat Feb 17 2018 kekepower <kekepower> 5.2.12-1.mga7
+ Revision: 1202381
- Have to define the upstream_name since the rename of the project
- Complete the renaming to mp
- Provides mp-5
- Rename spec file from mp-5.spec to mp.spec
- Rename project from mp-5 to mp
- Renamed patch
- Update to 5.2.12 final
- Fixed a version naming error
- Fixed %%setup_compile_flags
- Added %%docs
- Added %%find_lang

* Fri Feb 16 2018 kekepower <kekepower> 5.2.12dev-0.20180212_gitce894e5.1.mga7
+ Revision: 1201702
- Update to version 5.2.12dev-0.20180212_gitce894e5
- Add patch to enable ANSI colors

* Fri Feb 16 2018 kekepower <kekepower> 5.2.11-3.mga7
+ Revision: 1201693
- Added BR for grutatxt, which in turn builds the man page

* Thu Feb 15 2018 kekepower <kekepower> 5.2.11-2.mga7
+ Revision: 1201595
- Added BR for pcre-devel
- Added a few more configure options
- Fixed the %%files section a little

* Thu Feb 01 2018 kekepower <kekepower> 5.2.11-1.mga7
+ Revision: 1198468
- Add bison BR
- Add flex BR
- imported package mp-5

